import boto3
import base64
import os
import subprocess
from phcli.ph_max_auto import define_value as dv
from phcli.ph_max_auto.ph_hook.get_abs_path import get_asset_path_prefix, get_run_time
from phcli.ph_aws.ph_s3 import PhS3
from phcli.ph_aws.ph_sts import PhSts


def copy_asset_data(kwargs):

    result_path_prefix = kwargs['result_path_prefix']
    asset_path_prefix = get_asset_path_prefix(kwargs)
    run_time = get_run_time()
    ls_cmd = "aws s3 ls " + result_path_prefix
    source_file_path_keys = os.popen(ls_cmd).readlines()
    for source_file_path_key in source_file_path_keys:
        source_file_path_key = source_file_path_key.lstrip("                           PRE ").rstrip("\n")
        if '_asset' in source_file_path_key:
            asset_path = asset_path_prefix + source_file_path_key + run_time + "/"
            result_path = result_path_prefix + source_file_path_key
            cp_cmd = ["aws", "s3", "sync", result_path, asset_path]
            subprocess.call(cp_cmd)


if __name__ == '__main__':
    kwargs = {
        'path_prefix': 's3://ph-max-auto/2020-08-11/data_matching/refactor/runs/',
        'result_path_prefix': 's3://ph-max-auto/2020-08-11/data_matching/refactor/runs/manual__2021-01-18T04:49:20.117595+00:00/cleaning_data_normalization/',
        'dag_name': 'test_dag',
        'name': 'test_job',
        'run_id': 'test_run_id'
    }
    copy_asset_data(kwargs)



# -*- coding: utf-8 -*-

import copy
from phcli.ph_data_clean.clean.common_func import *
from phcli.ph_data_clean.clean.data_clean import DataClean
from phcli.ph_data_clean.mapping.universe_mapping import *


def define_tag_err_for_each(raw_data, mapping, final_data):
    tag_value = Tag.UNDEFINED

    if raw_data == {}:  # 若原始数据为空
        tag_value = Tag.EMPTY_DICT
        error_msg = 'Error message: empty raw_data'

    elif final_data == {}:  # 若最终字典没有内容
        tag_value = Tag.EMPTY_DICT
        error_msg = 'Error message: no mapping found'

    else:
        error_msg_flag = False
        warning_msg_flag = False
        error_msg = 'Col_missing:'
        warning_lst = []
        for maps in mapping:
            null_data_lst = ["#N/A", "-", "#########", "", "0", "0.0", 0, None]
            # 若某些必须有的列缺失数据
            if (maps['not_null']) and (maps['msg_type'] == 'err') \
                    and (final_data[maps['col_name']] in null_data_lst):
                error_msg_flag = True
                tag_value = Tag.MISSING_COL
                error_msg += ' / err: ' + maps['col_name']
                final_data[maps['col_name']] = reformat_null(data_type=maps['type'])
                # continue

            elif (maps['not_null']) and (maps['msg_type'] == 'warning') \
                    and (final_data[maps['col_name']] in null_data_lst):
                warning_msg_flag = True
                error_msg += ' / warning: ' + maps['col_name']
                warning_lst.append(maps['col_name'])

            elif (not maps['not_null']) and \
                    (final_data[maps['col_name']] in null_data_lst):
                final_data[maps['col_name']] = reformat_null(data_type=maps['type'])

        # 只有warning，没有err的情况
        if (not error_msg_flag) and warning_msg_flag:
            tag_value = Tag.WARNING
            error_msg = 'Warning: ' + str(warning_lst)

        # 没有warning和err， 也就是全部success的情况
        elif (not error_msg_flag) and (not warning_msg_flag):
            tag_value = Tag.SUCCESS
            error_msg = 'Success'

        return CleanResult(data=final_data,
                           metadata={},
                           raw_data=raw_data,
                           tag=tag_value,
                           err_msg=error_msg)


class UniverseDataClean(DataClean):
    """
    universe 源数据的清洗规则
    """

    def change_key_for_blue(self, *args, **kwargs):
        mapping = args[0]
        raw_data = kwargs['prev']

        # standardise column name
        new_key_name = {}
        for raw_data_key in raw_data.keys():
            old_key = raw_data_key.strip()  # remove unwanted symbols
            for m in mapping:
                if old_key.lower() in [key.lower() for key in m["candidate"]]:
                    new_key = m["col_name"]
                    if new_key not in new_key_name:
                        new_key_name[new_key] = raw_data[raw_data_key]  # write new key name into dict

        # create ordered new dict
        final_data = {}
        for m in mapping:
            for n in new_key_name.keys():
                if m["col_name"] == n:
                    final_data[m["col_name"]] = new_key_name[n]
                elif m["col_name"] not in final_data.keys():
                    final_data[m["col_name"]] = None
        final_data["UPDATE_LABEL"] = '2013_updated'

        return final_data

    def change_key_for_grey_orange(self, *args, **kwargs):
        raw_data = args[1]
        final_data_blue = kwargs['prev']
        final_data_for_three = []
        final_data_gery = copy.deepcopy(final_data_blue)
        final_data_orange = copy.deepcopy(final_data_blue)
        blue_grey_mapping = universe_blue_grey_mapping()
        blue_orange_mapping = universe_blue_orange_mapping()

        # 基于蓝色数据改2011年（灰色）数据
        for m in blue_grey_mapping:
            for name in m['grey_col_name']:
                if m["blue_col_name"] in final_data_gery and name in raw_data:
                    final_data_gery[m["blue_col_name"]] = raw_data[name]
        final_data_gery["UPDATE_LABEL"] = '2011_initial'

        # 基于蓝色数据改2019年（橙色）数据
        for m in blue_orange_mapping:
            for name in m['orange_col_name']:
                if m["blue_col_name"] in final_data_orange and name in raw_data:
                    final_data_orange[m["blue_col_name"]] = raw_data[name]
        final_data_orange["UPDATE_LABEL"] = '2019_updated'

        final_data_for_three.append(final_data_blue)  # 2013
        final_data_for_three.append(final_data_gery)  # 2011
        final_data_for_three.append(final_data_orange)  # 2019

        return final_data_for_three

    def reformat_true(self, *args, **kwargs):
        mapping = args[0]
        final_data_for_three = kwargs['prev']

        for final_data in final_data_for_three:
            for m in mapping:
                if m["type"] == "Boolean" and final_data[m["col_name"]] in [1, 1.0, "1", "1.0"]:
                    final_data[m["col_name"]] = True

        return final_data_for_three

    def define_tag_err_for_three(self, *args, **kwargs):
        mapping = args[0]
        raw_data = args[1]
        final_data_for_three = kwargs['prev']
        clean_result = {}

        for final_data in final_data_for_three:
            clean_result[final_data["UPDATE_LABEL"]] = \
                define_tag_err_for_each(raw_data=raw_data, mapping=mapping, final_data=final_data)

        return clean_result["2013_updated"], clean_result["2011_initial"], clean_result["2019_updated"]

    process = [
        check_format,
        change_key_for_blue,
        change_key_for_grey_orange,
        reformat_true,
        define_tag_err_for_three,
    ]



def mapping():
    return [
        {
            "col_name": "UPDATE_LABEL",
            "col_desc": "第几年更新的版本",
            "candidate": [],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "COMPANY",
            "col_desc": "数据公司",
            "candidate": [],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SOURCE",
            "col_desc": "数据来源",
            "candidate": [],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "TAG",
            "col_desc": "文件标识",
            "candidate": ['_TAG'],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "PHA_ID",
            "col_desc": "PHA ID",
            "candidate": ["5#新版ID"],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "PHA_HOSP_NAME",
            "col_desc": "医院名称",
            "candidate": ["6#新版名称"],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "REGION",
            "col_desc": "地区",
            "candidate": ["12#Region", "9#Region"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "PROVINCE",
            "col_desc": "省份名",
            "candidate": ["14#Province", "11#Province"],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "CITY",
            "col_desc": "城市名",
            "candidate": ["15#City", "12#City"],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "CITY_TIER",
            "col_desc": "城市等级",
            "candidate": ["28#City Tier 2010", "28#City_Tier_2010"],
            "type": "String",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "DISTRICT",
            "col_desc": "区/县",
            "candidate": ["16#District"],
            "type": "String",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "LOCATION",
            "col_desc": "坐标",
            "candidate": ["13#location"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "AREA_STRUCT",
            "col_desc": "建筑面积",
            "candidate": ["77#建筑面积"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "AREA_MU",
            "col_desc": "占地面积(亩)",
            "candidate": ["75#占地面积(亩)", "75#占地面积_亩_"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "AREA_SQ_M",
            "col_desc": "占地面积(m2)",
            "candidate": ["76#占地面积(m2)", "76#占地面积_m2_"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "HOSP_LEVEL",
            "col_desc": "医院级别",
            "candidate": ["8#Hosp_level"],
            "type": "String",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "HOSP_QUALITY",
            "col_desc": "性质（公立/私立）",
            "candidate": ["9#性质"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "HOSP_TYPE",
            "col_desc": "医院类型",
            "candidate": ["17#Type"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SPECIALTY_CATE",
            "col_desc": "标准化（综合/专科）1",
            "candidate": ["29#Specialty_1"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SPECIALTY_ADMIN",
            "col_desc": "标准化（综合/专科）2",
            "candidate": ["30#Specialty_2"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "RE_SPECIALTY",
            "col_desc": "标准化（综合/专科）re-specialty",
            "candidate": ["33#Re-Speialty"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SPECIALTY_DETAIL",
            "col_desc": "标准化（综合/专科）3",
            "candidate": ["34#Specialty 3", "34#Specialty_3"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "MILITARY",
            "col_desc": "是否为军队医院",
            "candidate": ["10#军队"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "DOCT_BANK",
            "col_desc": "医生库医院",
            "candidate": ["11#医生库医院"],
            "type": "Boolean",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "BID_SAMPLE",
            "col_desc": "招标Sample",
            "candidate": [r"19#招标Sample\n(county HP)\n共有样本2303，县医院样本932", "19#招标Sample_(county HP)_共有样本2303，县医院样本932"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "EPILEPSY",
            "col_desc": "癫痫专科",
            "candidate": ["80#癫痫专科"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "生殖中心",
            "col_desc": "REPRODUCE",
            "candidate": ["81#生殖中心"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "DRUGINCOME_RMB",
            "col_desc": "西药收入",
            "candidate": ["35#Est_DrugIncome_RMB"],
            "type": "Double",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "EMPLOYEES_NUM",
            "col_desc": "在职员工人数",
            "candidate": ["71#在职员工人数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "DOCTORS_NUM",
            "col_desc": "医生数",
            "candidate": ["36#医生数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "AUTH_BED_NUM",
            "col_desc": "编制床位数",
            "candidate": ["73#编制床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OPEN_BED_NUM",
            "col_desc": "开放床位数",
            "candidate": ["74#开放床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "BED_NUM",
            "col_desc": "床位数",
            "candidate": ["37#床位数"],
            "type": "Integer",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "GENERAL_BED_NUM",
            "col_desc": "全科床位数",
            "candidate": ["39#全科床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "INTERNAL_BED_NUM",
            "col_desc": "内科床位数",
            "candidate": ["40#内科床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SURG_BED_NUM",
            "col_desc": "外科床位数",
            "candidate": ["41#外科床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OPHTH_BED_NUM",
            "col_desc": "眼科床位数",
            "candidate": ["42#眼科床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "ANNU_DIAG_TIME",
            "col_desc": "年诊疗人次",
            "candidate": ["43#年诊疗人次"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_DIAG_TIME",
            "col_desc": "门诊诊次",
            "candidate": ["44#门诊诊次"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "INTERNAL_DIAG_TIME",
            "col_desc": "内科诊次",
            "candidate": ["45#内科诊次"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SURG_DIAG_TIME",
            "col_desc": "外科诊次",
            "candidate": ["46#外科诊次"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "ADMIS_TIME",
            "col_desc": "入院人数",
            "candidate": ["47#入院人数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SURG_TIME",
            "col_desc": "住院病人手术人次数",
            "candidate": ["48#住院病人手术人次数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "MED_INCOME",
            "col_desc": "医疗收入",
            "candidate": ["49#医疗收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_INCOME",
            "col_desc": "门诊收入",
            "candidate": ["50#门诊收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_TREAT_INCOME",
            "col_desc": "门诊治疗收入",
            "candidate": ["51#门诊治疗收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_SURG_INCOME",
            "col_desc": "门诊手术收入",
            "candidate": ["52#门诊手术收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_INCOME",
            "col_desc": "住院收入",
            "candidate": ["53#住院收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "BED_INCOME",
            "col_desc": "住院床位收入",
            "candidate": ["54#住院床位收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_TREAT_INCOME",
            "col_desc": "住院治疗收入",
            "candidate": ["55#住院治疗收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_SURG_INCOME",
            "col_desc": "住院手术收入",
            "candidate": ["56#住院手术收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "DRUG_INCOME",
            "col_desc": "药品收入",
            "candidate": ["57#药品收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_DRUG_INCOME",
            "col_desc": "门诊药品收入",
            "candidate": ["58#门诊药品收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_WST_DRUG_INCOME",
            "col_desc": "门诊西药收入",
            "candidate": ["59#门诊西药收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_DRUG_INCOME",
            "col_desc": "住院药品收入",
            "candidate": ["60#住院药品收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_WST_DRUG_INCOME",
            "col_desc": "住院西药收入",
            "candidate": ["61#住院西药收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "COUNTY_HOSP_WST_DRUG_INCOME",
            "col_desc": "2017年县医院西药收入",
            "candidate": ["62#2017年县医院西药收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
    ]



# -*- coding: utf-8 -*-

import os


class PhLocalStorage:

    def remove(self, path):
        try:
            os.remove(path)
        except IOError:
            return False
        else:
            return True

    def createDir(self, path):
        try:
            if not os.path.exists(path):
                print("create path ", path)
                os.makedirs(path)
        except IOError:
            return ""
        else:
            return path



import io
import setuptools
from glob import glob
from phcli.define_value import CLI_CLIENT_VERSION


with io.open("./README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="phcli",
    version=CLI_CLIENT_VERSION,
    author="Alfred Yang",
    author_email="alfredyang@pharbers.com",
    maintainer="ClockQ,AlexQian,hbzhao",
    maintainer_email="zyqi@pharbers.com,pqian@pharbers.com,15847059648@163.com",
    description="pharbers dag scheduler config",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=2.7',
    install_requires=[
        "requests",
        "click",
        "boto3",
        "pyyaml",
        "pandas",
        "xlrd",
        "pypinyin",
        "psycopg2",
        "sqlalchemy",
        "pymysql",
    ],
    package_data={
        '': ['template/*.yaml', 'template/*.tmp'],
    },
    data_files=[
        ('', glob('file/ph_data_clean/mapping_table/*')),
    ],
    entry_points={
        'console_scripts': [
            'phcli = phcli.__main__:phcli',
        ],
    }
)



# -*- coding: utf-8 -*-

import sys
import os
import json
import click
from phcli.ph_errs.ph_err import PhException
from phcli.ph_data_clean.clean.cleaner_factory import CleanerFactory
from phcli.ph_data_clean.model.mapping_factory import MappingFactory
from phcli.ph_data_clean.model.clean_result import CleanResult, Tag


def block_print():
    sys.stdout = open(os.devnull, 'w')


def enable_print():
    sys.stdout = sys.__stdout__


def clean(rd):
    """
    选择清洗算法和匹配表，并对结果进行包装
    :param rd: 原始数据，数据格式为 [{rawdata},{metadata}]
    :return: CleanResult
    """
    metadata = json.loads(rd['metadata'])
    source = metadata['providers'][1]
    company = metadata['providers'][0]

    cleaner = CleanerFactory().get_specific_cleaner(source, company)
    mapping = MappingFactory().get_specific_mapping(source, company)

    result = cleaner.cleaning_process(mapping, json.loads(rd['data']))
    for res in result:
        if res.tag.value > 0:
            res.data['SOURCE'] = source
            res.data['COMPANY'] = company

    return result


@click.command("clean", short_help='源数据清洗与 Schema 统一')
@click.argument("raw_data")
def main(raw_data):
    """
    Python 实现的数据清洗，并根据 Source 和 Company 选择清洗算法和清洗结构，以此同源数据的 Schema 统一
    """
    block_print()
    try:
        result = clean(json.loads(raw_data))
        enable_print()
    except PhException as err:
        rd = json.loads(raw_data)
        result = CleanResult(data={}, metadata={}, raw_data=json.loads(rd['data']), tag=Tag.PH_ERR, err_msg=str(err))

    sys.stdout.write(str(result))
    sys.stdout.flush()


if __name__ == '__main__':
    main()






# -*- coding: utf-8 -*-

import click
from phcli.ph_lmd.model.__main__ import model
from phcli.ph_lmd.ph_deploy import deploy


@click.group("lmd", short_help='自动化部署一系列 Lambda 技术栈')
def main():
    """
    本脚本用于快速打包和部署 AWS Lambda 和 API Gateway
    """
    pass


main.add_command(model)
main.add_command(deploy)

if __name__ == '__main__':
    main()



import requests
import json
import click

AIRFLOW_DOMAIN = 'http://airflow.pharbers.com'
AIRFLOW_API_VERSION = '/api/v1'
BASE_URL = AIRFLOW_DOMAIN + AIRFLOW_API_VERSION
DAGS_URL = BASE_URL+'/dags'
DAG_URL = BASE_URL+'/dags/{dag_id}'
DAG_TASKS_URL = BASE_URL+'/dags/{dag_id}/tasks'
DAG_TASK_URL = BASE_URL+'/dags/{dag_id}/tasks/{task_id}'
DAG_RUNS_URL = BASE_URL+'/dags/{dag_id}/dagRuns'
auth_user = ()


def format_json_str(j):
    return json.dumps(j, sort_keys=True, indent=4, separators=(',', ':'))


@click.group("airflow")
@click.option("-u", "--user", help="验证用户", default=':')
def airflow(user):
    """
    airflow 管理
    """
    global auth_user
    auth_user = tuple(user.split(':'))


@airflow.group("dag")
def dag():
    """
    airflow DAG 管理
    """
    pass


@dag.command("list", short_help='列出符合条件的 DAG 信息')
@click.option("-o", "--owners", help="所有者", default=None)
@click.option("-t", "--include_tags", help="包含标签", default=None)
@click.option("-T", "--exclude_tags", help="排除标签", default='example, example2, example3')
def dag_list(**kwargs):
    result = requests.get(DAGS_URL, auth=auth_user).json()

    include_owners = [owner.strip() for owner in kwargs['owners'].split(',')] if kwargs['owners'] else []
    include_tags = [tag.strip() for tag in kwargs['include_tags'].split(',')] if kwargs['include_tags'] else []
    exclude_tags = [tag.strip() for tag in kwargs['exclude_tags'].split(',')] if kwargs['exclude_tags'] else []

    # 筛选 DAG
    dags = []
    for dag in result['dags']:
        # 按照 tag 筛选
        flag = False if include_tags else True
        for tag in [tag['name'] for tag in dag['tags']]:
            if tag in exclude_tags:
                flag = False
                break
            if tag in include_tags:
                flag = True
        if not flag:
            continue

        # 按照 owner 筛选
        flag = False if include_owners else True
        for owner in dag['owners']:
            if owner in include_owners:
                flag = True
        if not flag:
            continue

        dags.append(dag)
    result['dags'] = dags
    result['total_entries'] = len(dags)

    print(format_json_str(result))


@dag.command("summary", short_help='统计指定 DAG 的运行信息')
@click.option("--dag_id", help="DAG ID", default=None)
def dag_summary(**kwargs):
    dag_id = kwargs['dag_id']
    if not dag_id:
        click.secho(str('未指定 DAG ID'), fg='red', blink=True, bold=True)
        return

    dag_info = requests.get(DAG_URL.format(dag_id=dag_id), auth=auth_user).json()

    dag_task_list = requests.get(DAG_TASKS_URL.format(dag_id=dag_id), auth=auth_user).json()
    dag_info['tasks'] = dag_task_list

    dag_run_list = requests.get(DAG_RUNS_URL.format(dag_id=dag_id), params={'limit': 10000}, auth=auth_user).json()
    state_summary = {}
    for dag_run in dag_run_list['dag_runs']:
        state = dag_run['state']
        state_summary[state] = state_summary.get(state, 0) + 1
    dag_run_list['success_entries'] = state_summary.get('success', 0)
    dag_run_list['failed_entries'] = state_summary.get('failed', 0)
    dag_run_list['running_entries'] = state_summary.get('running', 0)
    dag_info['dag_runs'] = dag_run_list

    print(format_json_str(dag_info))


@dag.command("trigger", short_help='执行指定 DAG')
@click.option("--dag_id", help="DAG ID", default=None)
@click.argument('args', nargs=1, default="{}")
def dag_trigger(**kwargs):
    dag_id = kwargs['dag_id']
    if not dag_id:
        click.secho(str('未指定 DAG ID'), fg='red', blink=True, bold=True)
        return

    dag_trigger = requests.post(DAG_RUNS_URL.format(dag_id=dag_id),
                                json={"conf": json.loads(kwargs['args'])},
                                auth=auth_user).json()
    print(format_json_str(dag_trigger))


@airflow.group("task")
def task():
    """
    airflow TASK 管理
    """
    pass


@task.command("list", short_help='列出指定 DAG 的 TASK 信息')
@click.option("--dag_id", help="DAG ID")
@click.option("-ed", "--execution_date", help="TASK 启动时间")
def task_list_by_dag(**kwargs):
    dag_id = kwargs['dag_id']
    if not dag_id:
        click.secho(str('未指定 DAG ID'), fg='red', blink=True, bold=True)
        return






import click
from phcli.ph_admin import pg
from phcli.ph_admin.ph_models import Partner


@click.group("partner", short_help='公司管理工具')
def main():
    """
    公司管理工具
    """


@click.command("create", short_help='创建公司')
@click.option("-n", "--name", help="公司名", prompt="公司名")
@click.option("-a", "--address", help="公司地址", prompt="公司地址")
@click.option("-p", "--phoneNumber", help="公司电话", prompt="公司电话")
@click.option("-w", "--web", help="公司官网", prompt="公司官网")
def create_partner(**kwargs):
    kwargs['phoneNumber'] = kwargs.pop('phonenumber')
    result = pg.insert(Partner(**kwargs))
    click.secho('添加成功'+str(result), fg='green', blink=True, bold=True)
    pg.commit()


@click.command("update", short_help='更新公司')
def update_partner():
    click.secho('未实现', fg='red', blink=True, bold=True)
    pass


@click.command("list", short_help='列举公司')
def list_partner():
    for p in pg.query(Partner()):
        click.secho(str(p), fg='green', blink=True, bold=True)


@click.command("get", short_help='查找公司')
@click.option("-n", "--name", help="公司名", default=None)
@click.option("-a", "--address", help="公司地址", default=None)
@click.option("-p", "--phoneNumber", help="公司电话", default=None)
@click.option("-w", "--web", help="公司官网", default=None)
def get_partner(**kwargs):
    kwargs['phoneNumber'] = kwargs.pop('phonenumber')
    for p in pg.query(Partner(**kwargs)):
        click.secho(str(p), fg='green', blink=True, bold=True)


@click.command("delete", short_help='删除公司')
@click.option("-n", "--name", help="公司名", prompt="公司名")
def delete_partner(**kwargs):
    for p in pg.delete(Partner(**kwargs)):
        click.secho(str(p), fg='green', blink=True, bold=True)
    pg.commit()


main.add_command(create_partner)
main.add_command(update_partner)
main.add_command(list_partner)
main.add_command(get_partner)
main.add_command(delete_partner)



import click
from phcli.ph_aws_cli.init_conf.ph_init_conf import PhInitConf

@click.command('init_conf', short_help='aws cp hadoop和spark的conf')
@click.option("-c", "--cluster_id",
              prompt="The emr cluster_id is",
              help="The emr cluster_id.")
def aws_init(**kwargs):
    """
    初始化c9 hadoop和spark的conf文件
    """
    try:
        cluster_id = kwargs["cluster_id"]
        PhInitConf.init_conf(cluster_id=cluster_id)
    except Exception as e:
        click.secho("创建失败: " + str(e), fg='red', blink=True, bold=True)
    else:
        click.secho("创建完成", fg='green', blink=True, bold=True)


